## DataStructure and Algorithms Utilities for Python Developers

A library containing all the necessary efficient utility tools.

### Installation

```bash
pip install dsutils
```

### Get Started

```bash
from dsautils import BinarySearch

input_list = [3,4,1,9,7]
object = BinarySearch(input_list)
output = object.search(9)
print(output)
```